@@ -6,8 +6,8 @@
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
 #
+#     http://www.apache.org/licenses/LICENSE-2.0
 #
 #
 # Unless required by applicable law or agreed to in writing,
@@ -18,10 +18,18 @@
 # under the License.
 
 from aliyunsdkcore.request import RpcRequest
+from aliyunsdkcdn.endpoint import endpoint_data
+
 class ModifyPathCacheExpiredConfigRequest(RpcRequest):
 
 	def __init__(self):
 		RpcRequest.__init__(self, 'Cdn', '2014-11-11', 'ModifyPathCacheExpiredConfig')
+		self.set_method('POST')
+		if hasattr(self, "endpoint_map"):
+			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
+		if hasattr(self, "endpoint_regional"):
+			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
+
 
 	def get_SecurityToken(self):
 		return self.get_query_params().get('SecurityToken')
@@ -29,12 +37,6 @@ class ModifyPathCacheExpiredConfigRequest(RpcRequest):
 	def set_SecurityToken(self,SecurityToken):
 		self.add_query_param('SecurityToken',SecurityToken)
 
-	def get_ConfigID(self):
-		return self.get_query_params().get('ConfigID')
-
-	def set_ConfigID(self,ConfigID):
-		self.add_query_param('ConfigID',ConfigID)
-
 	def get_DomainName(self):
 		return self.get_query_params().get('DomainName')
 
@@ -63,4 +65,10 @@ class ModifyPathCacheExpiredConfigRequest(RpcRequest):
 		return self.get_query_params().get('TTL')
 
 	def set_TTL(self,TTL):
-		self.add_query_param('TTL',TTL)
\ No newline at end of file
+		self.add_query_param('TTL',TTL)
+
+	def get_ConfigID(self):
+		return self.get_query_params().get('ConfigID')
+
+	def set_ConfigID(self,ConfigID):
+		self.add_query_param('ConfigID',ConfigID)
\ No newline at end of file
